

"""
Case studies
"""

import pandas

import amrs.misc.chem
import smartcarb

from . import wind


def apr15():
    """
    Estimated CO2 emissions very large bias (52 Mt/yr instead of 20 Mt/yr)
    caused by increased background only in the plume. The increase is likely
    caused mainly by local emissions but also affected by the biosphere which
    reduces the anth. signal outside Berlin due update by biosphere that is not
    happening over Berlin.
    """
    pass


def nov3():
    """
    Low PBL (105 m above ground) with surface emissions relased in PBL and stack emissions
    released in free troposphere.
    """
    time = pandas.Timestamp('2015-11-03 11:00')
    rlon, rlat = smartcarb.cfg.rlon, smartcarb.cfg.rlat


    hhl, lon, lat, u, v, xm, u10, v10 = wind.read_3d_wind_fields('CO2', time)

    xv = amrs.misc.chem.convert_unit(xm, 'kg kg-1', 'ppmv', molar_mass='CO2')


    # 0-90 m above ground
    xv_pbl = xv[-3:].mean(0)
    u_pbl = u[-3:].mean(0)
    v_pbl = v[-3:].mean(0)

    # 100 - 350
    xv_trop = xv[-6:-3].mean(0)
    u_trop = u[-6:-3].mean(0)
    v_trop = v[-6:-3].mean(0)

    fig = smartcarb.map.make_cosmo_map(rlon, rlat, xv_pbl, fig_size=4,
                                       label='CO$_2$ mixing ratios (ppmv)', vmin=0,
                                       vmax=30, edgecolor='white')
    ax, _ = fig.get_axes()
    smartcarb.map.plot_wind_field(ax, u_pbl, v_pbl, color='white')

    ax.set_xlim(1.32, 2.71)
    ax.set_ylim(5.28, 6.48)

    fig = smartcarb.map.make_cosmo_map(rlon, rlat, xv_trop, fig_size=4,
                                       label='CO$_2$ mixing ratios (ppmv)', vmin=0,
                                       vmax=30, edgecolor='white')
    ax, _ = fig.get_axes()
    smartcarb.map.plot_wind_field(ax, u_trop, v_trop, color='white')

    ax.set_xlim(1.32, 2.71)
    ax.set_ylim(5.28, 6.48)
