
"""
Make figures for publication

"""

import os
import itertools
import sys

import matplotlib.pyplot as plt

import emiss


# load data
ts = emiss.io.read_all()

figure_path = '/output/SMARTCARB/output/mass-balance/figures/'


# annual means by constellation
for method in ['ana-vari', 'ana-const', 'co2-gauss', 'co2-sub-areas',
               'no2-gauss', 'no2-sub-areas']:

    if method != 'ana-const':
        is_constant = False
    else:
        is_constant = True

    for noise in ['low', 'medium', 'high']:
        for n_knots in [3]:
            emiss.vis.plot_annual_emissions_by_constellation(ts[method][noise],
                                                             n_knots=n_knots,
                                                             is_constant=is_constant)

            filename = os.path.join(figure_path,
                                    'CO2-Berlin_%s-noise_%s_annual-mean-by-nsats_%d-knots' %
                                    (noise, method, n_knots))
            plt.savefig(filename + '.png')
            plt.savefig(filename + '.pdf')
            plt.close()

sys.exit(0)



# time series of estimated emissions
for nsat, noise, n_knots in itertools.product(['3a', '6'],
                                              ['low', 'medium', 'high'],
                                              [3]):

    for method in ['ana-const', 'ana-vari', 'co2-gauss', 'co2-sub-areas',
                   'no2-gauss', 'no2-sub-areas']:

        emiss.vis.plot_ts('CO2', ts[method][noise], nsat=nsat,
                          use_cycle_error=(not method.startswith('ana')),
                          show_errors=True, n_knots=n_knots)

        pattern = 'CO2-Berlin_%s_%%s-sats_%%s-noise_%%d-knots' % method
        filename = pattern % (nsat, noise, n_knots)
        filename = os.path.join(figure_path, filename)
        plt.savefig(filename + '.png')
        plt.savefig(filename + '.pdf')
        plt.close()



# find overpass indices were all are valid
for method in ['ana-vari', 'ana-const', 'co2-gauss', 'co2-sub-areas',
               'no2-gauss', 'no2-sub-areas']:

    dataset = [ts[method][noise] for noise in ['low', 'medium', 'high']]
    emiss.vis.boxplot(dataset, nsat='6', vmin=-30, vmax=30, sample='same')

    filename = 'CO2-Berlin_%s_boxplots' % method
    filename = os.path.join(figure_path, filename)
    plt.savefig(filename + '.png')
    plt.savefig(filename + '.pdf')
    plt.close()


# TODO: boxplots with 'same' for all approches


# mean-bias histograms
for method in ['gauss', 'sub-areas']:
    for noise in ['low', 'medium', 'high']:

        # CO2-based
        emiss.vis.plot_mb_histograms(method=method, co2_ssp=noise,
                                     no2_ssp='none')

        filename = os.path.join(figure_path, 'CO2-Berlin_%s-noise_co2-%s_histogram' %
                                (noise, method))
        plt.savefig(filename + '.png')
        plt.savefig(filename + '.pdf')
        plt.close()

        # NO2-based plume detection
        emiss.vis.plot_mb_histograms(method=method, co2_ssp=noise,
                                     no2_ssp='high')

        filename = os.path.join(figure_path, 'CO2-Berlin_%s-noise_no2-%s_histogram' %
                                (noise, method))
        plt.savefig(filename + '.png')
        plt.savefig(filename + '.pdf')
        plt.close()














