

import os
import multiprocessing
import matplotlib.pyplot as plt
import numpy as np

import dplume
import emiss.gauss

"""
Estimate CO2 emissions of Berlin using plumes detected by Monte-Carlo
experiment. Only use nsat=6 scenario.
"""


out_path = '/project/kug/smartcarb/results/Berlin/flux_inversion/mass-balance/results_mc'


def do_mass_balance(filename, tracer, ssp, origin, co2_ssp, save_results=True):

    print(os.path.basename(filename))

    out_fname = os.path.join(
        out_path,
        '%s-%.1f' % (tracer, co2_ssp),
        os.path.splitext(os.path.basename(filename))[0]
    )

    d,r,c = emiss.gauss.gauss_1d(
        filename, origin=origin, show=False,
        constant_emissions=False, load_results=False,
        save_results=save_results, out_filename=out_fname,
        load_plume=True,

        co2_ssp = co2_ssp,

        # curve
        degree=2,
        dmin=15e3, dmax=np.inf,
        force_origin=True,

        # background
        bg_area=10,       # 10x10 neighborhood

        # wind speed
        wind_use_mean=True, #
        wind_hmin=0.0,      # Berlin: 0.0 m, Janschwalde: > 120 m
        wind_hmax=500.0,     #       500.0 m,             < 3000 m

        is_mce=True
    )
    plt.close("all")

    return d,r,c




def get_filenames(tracer, ssp, nsat=6, origin='Berlin'):

    # read results from plume detection
    ts = dplume.io.read_results(tracer, ssp, ns=37, q=0.99, nsat=nsat,
                                origin=origin, use_mc=True)

    # remove detected plumes with small number of pixels
    # or many misdetections
    ts = ts[(ts.CO2_TP >= 100.0) & (ts.CO2_PPV >= 0.80)]

    return ts.filename


def main(tracer='CO2', ssp=0.5, origin='Berlin', co2_ssp=None, nsat=6, ncpu=24):

    if tracer == 'CO2':
        co2_ssp = ssp

    # read results from plume detection
    ts = dplume.io.read_results(tracer, ssp, ns=37, q=0.99, nsat=nsat,
                                origin=origin, use_mc=True)

    # remove detected plumes with small number of pixels
    # or many misdetections
    ts = ts[(ts.CO2_TP >= 100.0) & (ts.CO2_PPV >= 0.80)]

    print('number of files:', ts.shape[0])

    args = [(fn, tracer, ssp, origin, co2_ssp) for fn in ts.filename]

    with multiprocessing.Pool(ncpu) as pool:
        pool.starmap(do_mass_balance, args)

    # collect results
    path = os.path.join(out_path, '%s-%.1f' % (tracer, co2_ssp))
    frame = emiss.gauss.results2timeseries(path)

    filename = os.path.join(out_path, '%s-%.1fppm_%s.dat' % (tracer, co2_ssp,
                                                          origin))
    frame.to_csv(filename, sep='\t')



if __name__ == '__main__':
    main('CO2', 0.5)
    main('CO2', 0.7)
    main('CO2', 1.0)
    #main('NO2', 'high', co2_ssp=0.5)
    main('NO2', 'high', co2_ssp=0.7)
    main('NO2', 'high', co2_ssp=1.0)



