
import os
import multiprocessing
import numpy as np

import dplume
import emiss.gauss

"""
Estimate CO2 emissions of Berlin using plumes detected by Monte-Carlo
experiment. Only use nsat=6 scenario.
"""


out_path = '/project/kug/smartcarb/results/Janschwalde/flux_inversion/mass-balance/'


def do_mass_balance(filename, tracer, ssp, origin, co2_ssp=None):

    print(os.path.basename(filename))

    out_fname = os.path.join(
        out_path,
        '%s-%.1f' % (tracer, ssp if co2_ssp is None else co2_ssp),
        os.path.splitext(os.path.basename(filename))[0]
    )

    emiss.gauss.gauss_1d(
        filename, origin=origin, show=False,
        constant_emissions=False, load_results=False,
        save_results=True, out_filename=out_fname,
        load_plume=True,

        co2_ssp = co2_ssp,

        # curve
        degree=2,
        dmin=1e3, dmax=np.inf,
        force_origin=True,

        # background
        bg_area=10,       # 10x10 neighborhood

        # wind speed
        wind_use_mean=True, #
        wind_hmin=200.0,      # Berlin: 0.0 m, Janschwalde: > 120 m
        wind_hmax=400.0       #       500.0 m,             < 3000 m
    )


def main(tracer='CO2', ssp=0.5, origin='Janschwalde', co2_ssp=None, nsat=6, ncpu=24):

    if tracer == 'CO2':
        co2_ssp = None

    # read results from plume detection
    ts = dplume.io.read_results(tracer, ssp, ns=5, q=0.99, nsat=nsat,
                                origin=origin, use_mc=False)

    # remove detected plumes with small number of pixels
    # or multiple detections
    ts = ts[(ts.CO2_pixels >= 10.0) & (ts.multiple_detections == 0)]

    print('number of files:', ts.shape[0])

    args = [(fn, tracer, ssp, origin, co2_ssp) for fn in ts.filename]

    with multiprocessing.Pool(ncpu) as pool:
        pool.starmap(do_mass_balance, args)



if __name__ == '__main__':
    main('CO2', 0.5)
    main('CO2', 0.7)
    main('CO2', 1.0)
    #main('NO2', 'high', co2_ssp=0.5)
    #main('NO2', 'high', co2_ssp=0.7)
    #main('NO2', 'high', co2_ssp=1.0)



